==> haskell-tostring-0.2.1.1-170.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-Eh6CPV5V4MiJkaoeaPZgQ4
key:                  tostring-0.2.1.1-Eh6CPV5V4MiJkaoeaPZgQ4
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  cc35ea1fcc7abaed7f138fa0c5d80d3a
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-Eh6CPV5V4MiJkaoeaPZgQ4
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    text-2.0.2 utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tostring-0.2.1.1-171-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-2AwJ5wHIlzbEVz9u9SJyni
key:                  tostring-0.2.1.1-2AwJ5wHIlzbEVz9u9SJyni
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  d813d2b743d8a0c5254ec3503ee9f89a
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-2AwJ5wHIlzbEVz9u9SJyni
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    text-2.0.2 utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
